@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
 
 __author__ = 'F. A. Bastiaan von Meijenfeldt'
-__version__ = '5.2'
-__date__ = '20 November, 2020'
+__version__ = '5.2.1'
+__date__ = '6 January, 2021'
